@@ -5,8 +5,8 @@
 ;; Author: Robb Enzmann <robbenzmann@gmail.com>
 ;; Keywords: treesitter auto automatic major mode fallback convenience
 ;; URL: https://github.com/renzmann/treesit-auto.git
-;; Package-Version: 1.0.9
-;; Package-Revision: v1.0.9-0-ge10d10adcf1a
+;; Package-Version: 20260210.2010
+;; Package-Revision: 31466e4ccfd4
 ;; Package-Requires: ((emacs "29.0"))
 
 ;; This file is not part of GNU Emacs.
@@ -244,10 +244,6 @@ by manipulating the `treesit-auto-recipe-list' variable."
       :revision "master"
       :source-dir "src"
       :ext "\\.js\\'")
-    ,(make-treesit-auto-recipe
-      :lang 'jsdoc
-      :ts-mode 'php-ts-mode
-      :url "https://github.com/tree-sitter/tree-sitter-jsdoc")
     ,(make-treesit-auto-recipe
       :lang 'json
       :ts-mode 'json-ts-mode
@@ -318,13 +314,10 @@ by manipulating the `treesit-auto-recipe-list' variable."
     ,(make-treesit-auto-recipe
       :lang 'php
       :ts-mode 'php-ts-mode
+      :remap 'php-mode
       :url "https://github.com/tree-sitter/tree-sitter-php"
       :source-dir "php/src"
       :ext "\\.php\\'")
-    ,(make-treesit-auto-recipe
-      :lang 'phpdoc
-      :ts-mode 'php-ts-mode
-      :url "https://github.com/claytonrcarter/tree-sitter-phpdoc")
     ,(make-treesit-auto-recipe
       :lang 'proto
       :ts-mode 'protobuf-ts-mode
@@ -697,8 +690,10 @@ missing from `treesit-auto-langs', then it will not be added to
                         ((and langs (listp langs)) (treesit-auto--filter-recipes-with-langs langs selected-recipes))
                         (t (seq-filter #'treesit-auto--recipe-ready-p selected-recipes)))))
     (dolist (r recipes)
-      (add-to-list 'auto-mode-alist
-                   (cons (treesit-auto-recipe-ext r) (treesit-auto-recipe-ts-mode r))))))
+      (let ((ext (treesit-auto-recipe-ext r)))
+        (unless (null ext)
+          (add-to-list 'auto-mode-alist
+                       (cons ext (treesit-auto-recipe-ts-mode r))))))))
 
 (provide 'treesit-auto)
 ;;; treesit-auto.el ends here
